**# Const Package

## Introduction

infi_const is a package that have the const to navad project.

## Installation

Install the package via pipenv:

    pipenv install infi_const

## Features

- const url
- const utils


## more info
### const in the package:
- EMAIL_LIST_NAVAD
- EMAIL_TEST_LIST
- RABBIT QUEUES
- TGV_API_URL
- AZCOPY_API_URL
- SKYLINE_SERVICE_URL